@@ -34,6 +34,7 @@
 
 #include "ev-document.h"
 #include "ev-link.h"
+#include "ev-mapping-list.h"
 
 G_BEGIN_DECLS
 
@@ -60,26 +61,34 @@ struct _EvDocumentLinksInterface
 	GTypeInterface base_iface;
 
 	/* Methods  */
-	gboolean      (* has_document_links) (EvDocumentLinks *document_links);
-	GtkTreeModel *(* get_links_model)    (EvDocumentLinks *document_links);
-	GList        *(* get_links)          (EvDocumentLinks *document_links,
-					      EvPage          *page);
-	EvLinkDest   *(* find_link_dest)     (EvDocumentLinks *document_links,
-					      const gchar     *link_name);
+	gboolean       (* has_document_links) (EvDocumentLinks *document_links);
+	GtkTreeModel  *(* get_links_model)    (EvDocumentLinks *document_links);
+	EvMappingList *(* get_links)          (EvDocumentLinks *document_links,
+					       EvPage          *page);
+	EvLinkDest    *(* find_link_dest)     (EvDocumentLinks *document_links,
+					       const gchar     *link_name);
+	gint           (* find_link_page)     (EvDocumentLinks *document_links,
+					       const gchar     *link_name);
 };
 
-GType         ev_document_links_get_type           (void);
-gboolean      ev_document_links_has_document_links (EvDocumentLinks *document_links);
-GtkTreeModel *ev_document_links_get_links_model    (EvDocumentLinks *document_links);
+GType          ev_document_links_get_type            (void) G_GNUC_CONST;
+gboolean       ev_document_links_has_document_links  (EvDocumentLinks *document_links);
+GtkTreeModel  *ev_document_links_get_links_model     (EvDocumentLinks *document_links);
 
-GList        *ev_document_links_get_links          (EvDocumentLinks *document_links,
-						    EvPage          *page);
-EvLinkDest   *ev_document_links_find_link_dest     (EvDocumentLinks *document_links,
-						    const gchar     *link_name);
-gint          ev_document_links_get_dest_page      (EvDocumentLinks *document_links,
-						    EvLinkDest      *dest);
-gchar        *ev_document_links_get_dest_page_label(EvDocumentLinks *document_links,
-						    EvLinkDest      *dest);
+EvMappingList *ev_document_links_get_links           (EvDocumentLinks *document_links,
+						      EvPage          *page);
+EvLinkDest    *ev_document_links_find_link_dest      (EvDocumentLinks *document_links,
+						      const gchar     *link_name);
+gint           ev_document_links_find_link_page      (EvDocumentLinks *document_links,
+						      const gchar     *link_name);
+gint           ev_document_links_get_dest_page       (EvDocumentLinks *document_links,
+						      EvLinkDest      *dest);
+gchar         *ev_document_links_get_dest_page_label (EvDocumentLinks *document_links,
+						      EvLinkDest      *dest);
+gint           ev_document_links_get_link_page       (EvDocumentLinks *document_links,
+						      EvLink          *link);
+gchar         *ev_document_links_get_link_page_label (EvDocumentLinks *document_links,
+						      EvLink          *link);
 
 G_END_DECLS
 
